==> kadaster-gds2-1.1-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandenlijstgbopvragen/v20130701/ObjectFactory.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandenlijstgbopvragen.v20130701;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the nl.kadaster.schemas.gds2.afgifte_bestandenlijstgbopvragen.v20130701 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _BestandenlijstGbOpvragen_QNAME = new QName("http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstgbopvragen/v20130701", "BestandenlijstGbOpvragen");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: nl.kadaster.schemas.gds2.afgifte_bestandenlijstgbopvragen.v20130701
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link BestandenlijstGbOpvragenType }
     * 
     */
    public BestandenlijstGbOpvragenType createBestandenlijstGbOpvragenType() {
        return new BestandenlijstGbOpvragenType();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link BestandenlijstGbOpvragenType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstgbopvragen/v20130701", name = "BestandenlijstGbOpvragen")
    public JAXBElement<BestandenlijstGbOpvragenType> createBestandenlijstGbOpvragen(BestandenlijstGbOpvragenType value) {
        return new JAXBElement<BestandenlijstGbOpvragenType>(_BestandenlijstGbOpvragen_QNAME, BestandenlijstGbOpvragenType.class, null, value);
    }

}

==> kadaster-gds2-2.0-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandenlijstgbopvragen/v20130701/ObjectFactory.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandenlijstgbopvragen.v20130701;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the nl.kadaster.schemas.gds2.afgifte_bestandenlijstgbopvragen.v20130701 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _BestandenlijstGbOpvragen_QNAME = new QName("http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstgbopvragen/v20130701", "BestandenlijstGbOpvragen");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: nl.kadaster.schemas.gds2.afgifte_bestandenlijstgbopvragen.v20130701
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link BestandenlijstGbOpvragenType }
     * 
     */
    public BestandenlijstGbOpvragenType createBestandenlijstGbOpvragenType() {
        return new BestandenlijstGbOpvragenType();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link BestandenlijstGbOpvragenType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link BestandenlijstGbOpvragenType }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstgbopvragen/v20130701", name = "BestandenlijstGbOpvragen")
    public JAXBElement<BestandenlijstGbOpvragenType> createBestandenlijstGbOpvragen(BestandenlijstGbOpvragenType value) {
        return new JAXBElement<BestandenlijstGbOpvragenType>(_BestandenlijstGbOpvragen_QNAME, BestandenlijstGbOpvragenType.class, null, value);
    }

}
